@@ -1279,8 +1279,7 @@ func TestRemoveContainerNotFound(t *testing.T) {
 	server := baseDockerServer()
 	server.buildMuxer()
 	recorder := httptest.NewRecorder()
-	path := fmt.Sprintf("/containers/abc123")
-	request, _ := http.NewRequest(http.MethodDelete, path, nil)
+	request, _ := http.NewRequest(http.MethodDelete, "/containers/abc123", nil)
 	server.ServeHTTP(recorder, request)
 	if recorder.Code != http.StatusNotFound {
 		t.Errorf("RemoveContainer: wrong status. Want %d. Got %d.", http.StatusNotFound, recorder.Code)
@@ -2470,7 +2469,7 @@ func TestListVolumes(t *testing.T) {
 
 	gotVolumes, ok := got["Volumes"]
 	if !ok {
-		t.Fatal(fmt.Errorf("ListVolumes failed can not find Volumes"))
+		t.Fatal("ListVolumes failed can not find Volumes")
 	}
 	if !reflect.DeepEqual(gotVolumes, expected) {
 		t.Errorf("ListVolumes.  Want %#v.  Got %#v.", expected, got)
